@@ -9,15 +9,17 @@
 
 #include "konsoledebug.h"
 
+// Qt
+#include <QStringList>
+#include <qplatformdefs.h>
+
+#ifndef Q_OS_WIN
+
 // System
 #include <csignal>
 #include <sys/ioctl.h> //ioctl() and TIOCSWINSZ
 #include <termios.h>
 
-// Qt
-#include <QStringList>
-#include <qplatformdefs.h>
-
 // KDE
 #include <KPtyDevice>
 #include <kpty_version.h>
@@ -339,4 +341,144 @@ void Pty::setupChildProcess()
         sigaction(signal, &action, nullptr);
     }
 }
+#endif // QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+
+#else // Windows backend
+
+#include "ptyqt/conptyprocess.h"
+
+using Konsole::Pty;
+
+Pty::Pty(QObject *aParent)
+    : Pty(-1, aParent)
+{
+}
+
+Pty::Pty(int masterFd, QObject *aParent)
+    : QObject(aParent)
+{
+    Q_UNUSED(masterFd)
+
+    m_proc = std::make_unique<ConPtyProcess>();
+    if (!m_proc->isAvailable()) {
+        m_proc.reset();
+    }
+
+    _windowColumns = 0;
+    _windowLines = 0;
+    _windowWidth = 0;
+    _windowHeight = 0;
+    _eraseChar = 0;
+    _xonXoff = true;
+    _utf8 = true;
+
+    setEraseChar(_eraseChar);
+}
+
+Pty::~Pty() = default;
+
+void Pty::sendData(const QByteArray &data)
+{
+    if (m_proc) {
+        m_proc->write(data.constData(), data.length());
+    }
+}
+
+void Pty::dataReceived()
+{
+    if (m_proc) {
+        auto data = m_proc->readAll();
+        Q_EMIT receivedData(data.constData(), data.length());
+    }
+}
+
+void Pty::setWindowSize(int columns, int lines, int, int)
+{
+    if (m_proc && isRunning())
+        m_proc->resize(columns, lines);
+}
+
+QSize Pty::windowSize() const
+{
+    if (!m_proc) {
+        return {};
+    }
+    auto s = m_proc->size();
+    return QSize(s.first, s.second);
+}
+
+QSize Pty::pixelSize() const
+{
+    return QSize();
+}
+
+void Pty::setFlowControlEnabled(bool enable)
+{
+    _xonXoff = enable;
+}
+
+bool Pty::flowControlEnabled() const
+{
+    return false;
+}
+
+void Pty::setUtf8Mode(bool)
+{
+}
+
+void Pty::setEraseChar(char eChar)
+{
+    _eraseChar = eChar;
+}
+
+char Pty::eraseChar() const
+{
+    return _eraseChar;
+}
+
+void Pty::setInitialWorkingDirectory(const QString & /*dir*/)
+{
+}
+
+void Pty::addEnvironmentVariables(const QStringList & /*environmentVariables*/)
+{
+}
+
+int Pty::start(const QString &program, const QStringList &arguments, const QString &workingDir, const QStringList &environment, int cols, int lines)
+{
+    if (!m_proc || !m_proc->isAvailable()) {
+        return -1;
+    }
+    bool res = m_proc->startProcess(program, arguments, workingDir, environment, cols, lines);
+    if (!res) {
+        return -1;
+    } else {
+        auto n = m_proc->notifier();
+        connect(n, &QIODevice::readyRead, this, &Pty::dataReceived);
+        connect(m_proc.get(), &IPtyProcess::exited, this, [this] {
+            Q_EMIT finished(exitCode(), QProcess::NormalExit);
+        });
+        connect(n, &QIODevice::aboutToClose, this, [this] {
+            Q_EMIT finished(exitCode(), QProcess::NormalExit);
+        });
+    }
+    return 0;
+}
+
+void Pty::setWriteable(bool)
+{
+}
+
+void Pty::closePty()
+{
+    if (m_proc) {
+        m_proc->kill();
+    }
+}
+
+int Pty::foregroundProcessGroup() const
+{
+    return 0;
+}
+
 #endif
