@@ -18,6 +18,7 @@
 #include "colorscheme/ColorScheme.h"
 #include "colorscheme/ColorSchemeEditor.h"
 #include "colorscheme/ColorSchemeViewDelegate.h"
+#include "konsoleprivate_export.h"
 
 #include "profile/Profile.h"
 #include "profile/ProfileGroup.h"
@@ -230,6 +231,7 @@ private Q_SLOTS:
     void toggleWordModeAttr(bool mode);
     void toggleWordModeAscii(bool mode);
     void toggleWordModeBrahmic(bool mode);
+    void toggleIgnoreWcWidth(bool ignore);
 
 private:
     Q_DISABLE_COPY(EditProfileDialog)
